# hackeeg-client-python
Python client software for [HackEEG TI ADS1299 Arduino shield](https://github.com/starcat-io/hackeeg-shield)

This software allows you to connect to a HackEEG system, configure it, and stream data to Python programs
or over the Internet via [Lab Streaming Layer](https://github.com/sccn/labstreaminglayer).

See more documentation at [HackEEG on Read The Docs](https://hackeeg-client-python.readthedocs.io/en/latest/).


